#
# This file is part of OpenClone.
#
# Copyright (C) 2009  David Gnedt
#
# OpenClone is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OpenClone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OpenClone.  If not, see <http://www.gnu.org/licenses/>.
#

major = 0
minor = 0
patch = 0
rev = 0
dev = False

if dev is True:
	dev_str = '+dev'

else:
	dev_str = ''

version_str = '%d.%d.%d%s' % (major, minor, patch, dev_str)
version_long_str = '%d.%d.%d%s (rev %s)' % (major, minor, patch, dev_str, rev)
